@@ -269,13 +269,15 @@ class ServiceDiscoveryProtocol(SOMEIPDatagramProtocol):
                 family=family, type=socket.SOCK_DGRAM, proto=socket.IPPROTO_UDP
             )
 
-            if family == socket.AF_INET6 and isinstance(
-                loop, getattr(asyncio, "ProactorEventLoop", ())
+            if (
+                family == socket.AF_INET6
+                and platform.python_version_tuple() < (3, 8, 4)
+                and isinstance(loop, getattr(asyncio, "ProactorEventLoop", ()))
             ):
                 prot.log.warning(
                     "ProactorEventLoop has issues with ipv6 datagram sockets!"
-                    " https://bugs.python.org/issue39148. workaround with"
-                    " asyncio.set_event_loop_policy("
+                    " https://bugs.python.org/issue39148. Update to Python>=3.8.4, or"
+                    " workaround with asyncio.set_event_loop_policy("
                     "asyncio.WindowsSelectorEventLoopPolicy())",
                 )
 
@@ -476,6 +478,16 @@ class ServiceDiscoveryProtocol(SOMEIPDatagramProtocol):
 
         self.send(hdr.build(), remote)
 
+    def start(self) -> None:
+        self.subscriber.start()
+        self.announcer.start()
+        self.discovery.start()
+
+    def stop(self) -> None:
+        self.discovery.stop()
+        self.announcer.stop()
+        self.subscriber.stop()
+
     def connection_lost(self, exc: typing.Optional[Exception]) -> None:
         log = self.log.exception if exc else self.log.info
         log("connection lost. stopping all child tasks", exc_info=exc)
@@ -833,6 +845,20 @@ class ServiceDiscover:
         self.watcher_all_services: typing.Set[ClientServiceListener] = set()
 
         self.found_services: TimedStore[someip.config.Service] = TimedStore(self.log)
+        self.task: typing.Optional[asyncio.Task[None]] = None
+
+    def start(self):
+        if self.task is not None and not self.task.done():  # pragma: nocover
+            return
+
+        loop = asyncio.get_running_loop()
+        self.task = loop.create_task(self.send_find_services())
+
+    def stop(self):
+        if self.task:  # pragma: nobranch
+            self.task.cancel()
+            asyncio.create_task(wait_cancelled(self.task))
+            self.task = None
 
     def handle_offer(
         self, entry: someip.header.SOMEIPSDEntry, addr: _T_SOCKADDR
@@ -858,6 +884,9 @@ class ServiceDiscover:
         self.watcher_all_services.add(listener)
 
     def find_subscribe_eventgroup(self, eventgroup: someip.config.Eventgroup):
+        # FIXME: ServiceSubscriber will probably introduce a delay of one refresh
+        # interval. workaround would be setting SUBSCRIBE_REFRESH_INTERVAL=0 and
+        # SUBSCRIBE_TTL=TTL_FOREVER
         self.watch_service(
             eventgroup.as_service(),
             AutoSubscribeServiceListener(self.sd.subscriber, eventgroup),
@@ -1039,6 +1068,25 @@ class ServiceAnnouncer:
             self.log.warning("adding services without going through startup phase")
         self.announcing_services.append((service, listener))
 
+    def stop_announce_service(
+        self, service: someip.config.Service, listener: ServerServiceListener,
+        send_stop=True,
+    ) -> None:
+        """
+        stops announcing previously started service
+
+        :param service: service definition of service to be stopped
+        :param listener: listener of service to be stopped
+        :raises ValueError: if the service was not announcing
+        """
+        self.announcing_services.remove((service, listener))
+        if send_stop and self.task is not None and not self.task.done():
+            asyncio.get_event_loop().call_soon(
+                functools.partial(
+                    self._send_offers, ((service, listener),), stop=True
+                ),
+            )
+
     @log_exceptions()
     async def handle_subscribe(
         self, entry: someip.header.SOMEIPSDEntry, addr: _T_SOCKADDR,
